==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Visual/analyzer/translations/analyzer_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="48"/>
        <source>Qmmp Analyzer</source>
        <translation>QMMP アナライザ</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Analyzer Plugin Settings</source>
        <translation>アナライザプラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Show peaks</source>
        <translation>ピーク表示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Analyzer falloff:</source>
        <translation>アナライザ減衰速度:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Slowest</source>
        <translation>さらに遅く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Slow</source>
        <translation>遅く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Medium</source>
        <translation>適度</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <location filename="../settingsdialog.ui" line="112"/>
        <source>Fast</source>
        <translation>速く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Fastest</source>
        <translation>さらに速く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Peaks falloff:</source>
        <translation>ピーク減衰速度:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="125"/>
        <source>Refresh rate:</source>
        <translation>再描画の頻度:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>50 FPS</source>
        <translation>50 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>25 FPS</source>
        <translation>25 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>10 FPS</source>
        <translation>10 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>5 FPS</source>
        <translation>5 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Colors</source>
        <translation>色</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="177"/>
        <source>Peaks:</source>
        <translation>峰:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #1:</source>
        <translation>第一アナライザ:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Background:</source>
        <translation>背景:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Analyzer #2:</source>
        <translation>第二アナライザ:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>Analyzer #3:</source>
        <translation>第三アナライザ:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>アナライザプラグイン</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>アナライザ視覚効果プラグインについて</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>QMMP アナライザ視覚効果プラグイン</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Visual/analyzer/translations/analyzer_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="51"/>
        <source>Qmmp Analyzer</source>
        <translation>QMMP アナライザー</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Analyzer Plugin Settings</source>
        <translation>アナライザープラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Show peaks</source>
        <translation>ピーク表示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Analyzer falloff:</source>
        <translation>アナライザー減衰速度:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Slowest</source>
        <translation>さらに遅く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Slow</source>
        <translation>遅く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Medium</source>
        <translation>適度</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <location filename="../settingsdialog.ui" line="112"/>
        <source>Fast</source>
        <translation>速く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Fastest</source>
        <translation>さらに速く</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Peaks falloff:</source>
        <translation>ピーク減衰速度:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="125"/>
        <source>Refresh rate:</source>
        <translation>再描画の頻度:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>50 FPS</source>
        <translation>50 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>25 FPS</source>
        <translation>25 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>10 FPS</source>
        <translation>10 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>5 FPS</source>
        <translation>5 フレーム毎秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Colors</source>
        <translation>色</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="177"/>
        <source>Peaks:</source>
        <translation>峰:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #1:</source>
        <translation>第一アナライザー:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Background:</source>
        <translation>背景:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Analyzer #2:</source>
        <translation>第二アナライザー:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>Analyzer #3:</source>
        <translation>第三アナライザー:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>アナライザープラグイン</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>アナライザー視覚効果プラグインについて</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>QMMP アナライザー視覚効果プラグイン</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
